==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnPropertySetterDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnPropertySetterDescription } from "./ColumnPropertySetterDescription";
/**
 * @hidden
 */
export let ColumnPropertySetterDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnPropertySetterDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnPropertySetterDescriptionMetadata.a == null) {
                ColumnPropertySetterDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnPropertySetterDescriptionMetadata.c(ColumnPropertySetterDescriptionMetadata.a);
            }
            if (a.k(ColumnPropertySetterDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnPropertySetterDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ColumnName", "String");
            a.item("PropertyName", "String");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        }
        static d(a) {
            ColumnPropertySetterDescriptionMetadata.b(a);
            a.ac("ColumnPropertySetter", () => new ColumnPropertySetterDescription());
            a.ab("ColumnPropertySetter", ColumnPropertySetterDescriptionMetadata.a);
        }
    }
    ColumnPropertySetterDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnPropertySetterDescriptionMetadata, 'ColumnPropertySetterDescriptionMetadata');
    ColumnPropertySetterDescriptionMetadata.a = null;
    return ColumnPropertySetterDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ColumnPropertySetterDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnPropertySetterDescription } from "./ColumnPropertySetterDescription";
/**
 * @hidden
 */
export let ColumnPropertySetterDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnPropertySetterDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnPropertySetterDescriptionMetadata.a == null) {
                ColumnPropertySetterDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnPropertySetterDescriptionMetadata.c(ColumnPropertySetterDescriptionMetadata.a);
            }
            if (a.k(ColumnPropertySetterDescriptionMetadata.a)) {
                return;
            }
            a.ac(ColumnPropertySetterDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ColumnName", "String");
            a.item("PropertyName", "String");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        }
        static d(a) {
            ColumnPropertySetterDescriptionMetadata.b(a);
            a.ae("ColumnPropertySetter", () => new ColumnPropertySetterDescription());
            a.ad("ColumnPropertySetter", ColumnPropertySetterDescriptionMetadata.a);
        }
    }
    ColumnPropertySetterDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnPropertySetterDescriptionMetadata, 'ColumnPropertySetterDescriptionMetadata');
    ColumnPropertySetterDescriptionMetadata.a = null;
    return ColumnPropertySetterDescriptionMetadata;
})();
